# Installation

Install FreeGenius AI, by running:

To set up virtual environment (recommended):

> mkdir -p ~/apps/freegenius

> cd ~/apps/freegenius

> python3 -m venv freegenius

> source freegenius/bin/activate

To install:

> pip install --upgrade freegenius

To run:

> freegenius

# Notes to Windows users:

Windows may also need to install cmake, rust and Microsoft Visual C++ 14.0 or greater.

For more information, read: https://github.com/eliranwong/letmedoit/wiki/Installation#windows-users
